@@ -122,6 +122,9 @@ FAILEDOPERATION_INSTANCENOTFOUND = 'FailedOperation.InstanceNotFound'
 # The instance is not running.
 FAILEDOPERATION_INSTANCENOTRUNNING = 'FailedOperation.InstanceNotRunning'
 
+# 
+FAILEDOPERATION_INTERNALERROR = 'FailedOperation.InternalError'
+
 # The resource already exists.
 FAILEDOPERATION_RESOURCEEXIST = 'FailedOperation.ResourceExist'
 
